@@ -3,8 +3,9 @@
 import click
 from datetime import datetime
 from nextcode import Client
-from nextcode.config import get_default_profile
+from nextcode.config import get_default_profile, clear_cache
 from nextcodecli.utils import print_tab, dumps
+from nextcode.utils import decode_token
 
 
 @click.command()
@@ -19,9 +20,11 @@ def cli(is_raw):
     """
     Print out an access token for the current profile
     """
+    clear_cache()
     client = Client()
     token = client.get_access_token(decode=False)
-    payload = client.get_access_token(decode=True)
+
+    payload = decode_token(token)
     profile = get_default_profile()
     if is_raw:
         ret = {"token": token, "payload": payload, "profile": profile}
