@@ -53,7 +53,7 @@ def pipelines(ctx, pipeline_name, is_raw, is_details, is_manifest):
             print_tab("Script", p['script'])
             print_tab("Revision", p['revision'] or 'latest')
             print_tab("Storage Type", p['storage_type'] or 'default')
-            print_tab("Scheduler", p['sscheduler_name'] or 'default')
+            print_tab("Scheduler", p['scheduler_name'] or 'default')
             for i, p in enumerate(p.get('parameters', [])):
                 txt = "%s (%s)" % (p['name'], p['type'])
                 if p.get('required'):
